@@ -7,7 +7,7 @@
 #ifndef NUCLEARCALCULATOR_H
 #define NUCLEARCALCULATOR_H
 
-#include <QDebug>
+#include "kalzium_debug.h"
 
 #include <KUnitConversion/UnitCategory>
 #include <KUnitConversion/Converter>
@@ -51,7 +51,7 @@ public:
     explicit nuclearCalculator(QWidget * parent = nullptr);
     ~nuclearCalculator();
 
-public slots:
+public Q_SLOTS:
     /// Calculates the initial amount and updates the UI
     void calculateInitAmount();
 
