@@ -7,7 +7,7 @@
 #ifndef TITRATIONCALCULATOR_H
 #define TITRATIONCALCULATOR_H
 
-#include <QDebug>
+#include "kalzium_debug.h"
 #include <QString>
 #include <QStringList>
 
@@ -35,7 +35,7 @@ public:
     explicit titrationCalculator(QWidget * parent = nullptr);
     ~titrationCalculator();
 
-public slots:
+public Q_SLOTS:
     void on_pushButton_clicked();
     void on_xmin_valueChanged(double val);
     void on_xmax_valueChanged(double val);
@@ -68,7 +68,6 @@ private:
     QString greenplot;
     QString blueplot;
 
-    Ui::titrationCalculator *ui;               // The user interface pointer
     Ui::titrationCalculator uid;               // The user interface
 };
 
