@@ -10,7 +10,7 @@
 
 #include <KLocalizedString>
 
-#include <QDebug>
+#include "kalzium_debug.h"
 #include <QFile>
 #include <QFileInfo>
 #include <QFontDatabase>
@@ -79,7 +79,7 @@ void DetailedGraphicalOverview::paintEvent(QPaintEvent*)
     } else if (Prefs::colorschemebox() == 2) { //The iconic view is the 3rd view (0,1,2,...)
         pm.fill(palette().window().color());
 
-        QString pathname = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("data/iconsets/"), QStandardPaths::LocateDirectory);
+        QString pathname = QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, QStringLiteral("data/iconsets/"), QStandardPaths::LocateDirectory);
 
         int enumii = m_element->dataAsVariant(ChemicalDataObject::atomicNumber).toInt();
 
